@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -45,7 +45,7 @@ except AttributeError:  # pragma: NO COVER
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.location import locations_pb2  # type: ignore
-from google.longrunning import operations_pb2
+from google.longrunning import operations_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 
 from google.cloud.tpu_v1.services.tpu import pagers
@@ -58,6 +58,7 @@ from .transports.grpc_asyncio import TpuGrpcAsyncIOTransport
 
 class TpuAsyncClient:
     """Manages TPU nodes and other resources
+
     TPU API v1
     """
 
@@ -1708,7 +1709,7 @@ class TpuAsyncClient:
         # Done; return the response.
         return response
 
-    async def __aenter__(self):
+    async def __aenter__(self) -> "TpuAsyncClient":
         return self
 
     async def __aexit__(self, exc_type, exc, tb):
