@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -49,7 +49,7 @@ except AttributeError:  # pragma: NO COVER
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.location import locations_pb2  # type: ignore
-from google.longrunning import operations_pb2
+from google.longrunning import operations_pb2  # type: ignore
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
@@ -100,6 +100,7 @@ class TpuClientMeta(type):
 
 class TpuClient(metaclass=TpuClientMeta):
     """Manages TPU nodes and other resources
+
     TPU API v2
     """
 
@@ -735,7 +736,6 @@ class TpuClient(metaclass=TpuClientMeta):
 
                 # Initialize request argument(s)
                 node = tpu_v2.Node()
-                node.accelerator_type = "accelerator_type_value"
                 node.runtime_version = "runtime_version_value"
 
                 request = tpu_v2.CreateNodeRequest(
@@ -1182,7 +1182,6 @@ class TpuClient(metaclass=TpuClientMeta):
 
                 # Initialize request argument(s)
                 node = tpu_v2.Node()
-                node.accelerator_type = "accelerator_type_value"
                 node.runtime_version = "runtime_version_value"
 
                 request = tpu_v2.UpdateNodeRequest(
