@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -24,8 +24,10 @@ from .types.cloud_tpu import (
     AcceleratorType,
     AccessConfig,
     AttachedDisk,
+    BootDiskConfig,
     CreateNodeRequest,
     CreateQueuedResourceRequest,
+    CustomerEncryptionKey,
     DeleteNodeRequest,
     DeleteQueuedResourceRequest,
     GenerateServiceIdentityRequest,
@@ -53,6 +55,7 @@ from .types.cloud_tpu import (
     OperationMetadata,
     QueuedResource,
     QueuedResourceState,
+    ResetQueuedResourceRequest,
     RuntimeVersion,
     SchedulingConfig,
     ServiceAccount,
@@ -71,8 +74,10 @@ __all__ = (
     "AcceleratorType",
     "AccessConfig",
     "AttachedDisk",
+    "BootDiskConfig",
     "CreateNodeRequest",
     "CreateQueuedResourceRequest",
+    "CustomerEncryptionKey",
     "DeleteNodeRequest",
     "DeleteQueuedResourceRequest",
     "GenerateServiceIdentityRequest",
@@ -100,6 +105,7 @@ __all__ = (
     "OperationMetadata",
     "QueuedResource",
     "QueuedResourceState",
+    "ResetQueuedResourceRequest",
     "RuntimeVersion",
     "SchedulingConfig",
     "ServiceAccount",
