@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -179,6 +179,11 @@ class TpuTransport(abc.ABC):
                 default_timeout=None,
                 client_info=client_info,
             ),
+            self.reset_queued_resource: gapic_v1.method.wrap_method(
+                self.reset_queued_resource,
+                default_timeout=None,
+                client_info=client_info,
+            ),
             self.generate_service_identity: gapic_v1.method.wrap_method(
                 self.generate_service_identity,
                 default_timeout=None,
@@ -331,6 +336,15 @@ class TpuTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def reset_queued_resource(
+        self,
+    ) -> Callable[
+        [cloud_tpu.ResetQueuedResourceRequest],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
+    ]:
+        raise NotImplementedError()
+
     @property
     def generate_service_identity(
         self,
