@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -33,6 +33,7 @@ class TpuGrpcTransport(TpuTransport):
     """gRPC backend transport for Tpu.
 
     Manages TPU nodes and other resources
+
     TPU API v2alpha1
 
     This class defines the same methods as the primary client, so the
@@ -533,6 +534,32 @@ class TpuGrpcTransport(TpuTransport):
             )
         return self._stubs["delete_queued_resource"]
 
+    @property
+    def reset_queued_resource(
+        self,
+    ) -> Callable[[cloud_tpu.ResetQueuedResourceRequest], operations_pb2.Operation]:
+        r"""Return a callable for the reset queued resource method over gRPC.
+
+        Resets a QueuedResource TPU instance
+
+        Returns:
+            Callable[[~.ResetQueuedResourceRequest],
+                    ~.Operation]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "reset_queued_resource" not in self._stubs:
+            self._stubs["reset_queued_resource"] = self.grpc_channel.unary_unary(
+                "/google.cloud.tpu.v2alpha1.Tpu/ResetQueuedResource",
+                request_serializer=cloud_tpu.ResetQueuedResourceRequest.serialize,
+                response_deserializer=operations_pb2.Operation.FromString,
+            )
+        return self._stubs["reset_queued_resource"]
+
     @property
     def generate_service_identity(
         self,
