@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -52,6 +52,7 @@ __protobuf__ = proto.module(
         "GetQueuedResourceRequest",
         "CreateQueuedResourceRequest",
         "DeleteQueuedResourceRequest",
+        "ResetQueuedResourceRequest",
         "ServiceIdentity",
         "GenerateServiceIdentityRequest",
         "GenerateServiceIdentityResponse",
@@ -70,6 +71,8 @@ __protobuf__ = proto.module(
         "SimulateMaintenanceEventRequest",
         "AcceleratorConfig",
         "ShieldedInstanceConfig",
+        "BootDiskConfig",
+        "CustomerEncryptionKey",
     },
 )
 
@@ -396,6 +399,11 @@ class Node(proto.Message):
             The AccleratorConfig for the TPU Node.
         shielded_instance_config (google.cloud.tpu_v2alpha1.types.ShieldedInstanceConfig):
             Shielded Instance options.
+        multislice_node (bool):
+            Output only. Whether the Node belongs to a
+            Multislice group.
+        boot_disk_config (google.cloud.tpu_v2alpha1.types.BootDiskConfig):
+            Optional. Boot disk configuration.
     """
 
     class State(proto.Enum):
@@ -603,6 +611,15 @@ class Node(proto.Message):
         number=45,
         message="ShieldedInstanceConfig",
     )
+    multislice_node: bool = proto.Field(
+        proto.BOOL,
+        number=47,
+    )
+    boot_disk_config: "BootDiskConfig" = proto.Field(
+        proto.MESSAGE,
+        number=49,
+        message="BootDiskConfig",
+    )
 
 
 class QueuedResource(proto.Message):
@@ -630,7 +647,11 @@ class QueuedResource(proto.Message):
 
             This field is a member of `oneof`_ ``tier``.
         guaranteed (google.cloud.tpu_v2alpha1.types.QueuedResource.Guaranteed):
-            The Guaranteed tier
+            The Guaranteed tier.
+
+            This field is a member of `oneof`_ ``tier``.
+        spot (google.cloud.tpu_v2alpha1.types.QueuedResource.Spot):
+            Optional. The Spot tier.
 
             This field is a member of `oneof`_ ``tier``.
         queueing_policy (google.cloud.tpu_v2alpha1.types.QueuedResource.QueueingPolicy):
@@ -667,10 +688,41 @@ class QueuedResource(proto.Message):
                     multi-node requests, multi_node_params must be populated
                     instead. It's an error to specify both node_id and
                     multi_node_params.
+                multi_node_params (google.cloud.tpu_v2alpha1.types.QueuedResource.Tpu.NodeSpec.MultiNodeParams):
+                    Optional. Fields to specify in case of
+                    multi-node request.
                 node (google.cloud.tpu_v2alpha1.types.Node):
                     Required. The node.
             """
 
+            class MultiNodeParams(proto.Message):
+                r"""Parameters to specify for multi-node QueuedResource requests. This
+                field must be populated in case of multi-node requests instead of
+                node_id. It's an error to specify both node_id and
+                multi_node_params.
+
+                Attributes:
+                    node_count (int):
+                        Required. Number of nodes with this spec. The system will
+                        attempt to provison "node_count" nodes as part of the
+                        request. This needs to be > 1.
+                    node_id_prefix (str):
+                        Prefix of node_ids in case of multi-node request Should
+                        follow the ``^[A-Za-z0-9_.~+%-]+$`` regex format. If
+                        node_count = 3 and node_id_prefix = "np", node ids of nodes
+                        created will be "np-0", "np-1", "np-2". If this field is not
+                        provided we use queued_resource_id as the node_id_prefix.
+                """
+
+                node_count: int = proto.Field(
+                    proto.INT32,
+                    number=1,
+                )
+                node_id_prefix: str = proto.Field(
+                    proto.STRING,
+                    number=2,
+                )
+
             parent: str = proto.Field(
                 proto.STRING,
                 number=1,
@@ -679,6 +731,13 @@ class QueuedResource(proto.Message):
                 proto.STRING,
                 number=2,
             )
+            multi_node_params: "QueuedResource.Tpu.NodeSpec.MultiNodeParams" = (
+                proto.Field(
+                    proto.MESSAGE,
+                    number=6,
+                    message="QueuedResource.Tpu.NodeSpec.MultiNodeParams",
+                )
+            )
             node: "Node" = proto.Field(
                 proto.MESSAGE,
                 number=3,
@@ -694,6 +753,9 @@ class QueuedResource(proto.Message):
     class BestEffort(proto.Message):
         r"""BestEffort tier definition."""
 
+    class Spot(proto.Message):
+        r"""Spot tier definition."""
+
     class Guaranteed(proto.Message):
         r"""Guaranteed tier definition.
 
@@ -813,6 +875,12 @@ class QueuedResource(proto.Message):
         oneof="tier",
         message=Guaranteed,
     )
+    spot: Spot = proto.Field(
+        proto.MESSAGE,
+        number=9,
+        oneof="tier",
+        message=Spot,
+    )
     queueing_policy: QueueingPolicy = proto.Field(
         proto.MESSAGE,
         number=5,
@@ -875,6 +943,9 @@ class QueuedResourceState(proto.Message):
             Further data for the suspended state.
 
             This field is a member of `oneof`_ ``state_data``.
+        state_initiator (google.cloud.tpu_v2alpha1.types.QueuedResourceState.StateInitiator):
+            Output only. The initiator of the
+            QueuedResources's current state.
     """
 
     class State(proto.Enum):
@@ -918,6 +989,17 @@ class QueuedResourceState(proto.Message):
             SUSPENDED (8):
                 The resources specified in the QueuedResource
                 request have been deleted.
+            WAITING_FOR_RESOURCES (9):
+                The QueuedResource request has passed initial validation and
+                has been persisted in the queue. It will remain in this
+                state until there are sufficient free resources to begin
+                provisioning your request. Wait times will vary
+                significantly depending on demand levels. When demand is
+                high, not all requests can be immediately provisioned. If
+                you need more reliable obtainability of TPUs consider
+                purchasing a reservation. To put a limit on how long you are
+                willing to wait, use `timing
+                constraints <https://cloud.google.com/tpu/docs/queued-resources#request_a_queued_resource_before_a_specified_time>`__.
         """
         STATE_UNSPECIFIED = 0
         CREATING = 1
@@ -928,6 +1010,25 @@ class QueuedResourceState(proto.Message):
         ACTIVE = 6
         SUSPENDING = 7
         SUSPENDED = 8
+        WAITING_FOR_RESOURCES = 9
+
+    class StateInitiator(proto.Enum):
+        r"""The initiator of the QueuedResource's SUSPENDING/SUSPENDED
+        state.
+
+        Values:
+            STATE_INITIATOR_UNSPECIFIED (0):
+                The state initiator is unspecified.
+            USER (1):
+                The current QueuedResource state was
+                initiated by the user.
+            SERVICE (2):
+                The current QueuedResource state was
+                initiated by the service.
+        """
+        STATE_INITIATOR_UNSPECIFIED = 0
+        USER = 1
+        SERVICE = 2
 
     class CreatingData(proto.Message):
         r"""Further data for the creating state."""
@@ -1018,6 +1119,11 @@ class QueuedResourceState(proto.Message):
         oneof="state_data",
         message=SuspendedData,
     )
+    state_initiator: StateInitiator = proto.Field(
+        proto.ENUM,
+        number=10,
+        enum=StateInitiator,
+    )
 
 
 class ListNodesRequest(proto.Message):
@@ -1317,6 +1423,14 @@ class DeleteQueuedResourceRequest(proto.Message):
             Required. The resource name.
         request_id (str):
             Idempotent request UUID.
+        force (bool):
+            If set to true, all running nodes belonging
+            to this queued resource will be deleted first
+            and then the queued resource will be deleted.
+            Otherwise (i.e. force=false), the queued
+            resource will only be deleted if its nodes have
+            already been deleted or the queued resource is
+            in the ACCEPTED, FAILED, or SUSPENDED state.
     """
 
     name: str = proto.Field(
@@ -1327,6 +1441,25 @@ class DeleteQueuedResourceRequest(proto.Message):
         proto.STRING,
         number=2,
     )
+    force: bool = proto.Field(
+        proto.BOOL,
+        number=3,
+    )
+
+
+class ResetQueuedResourceRequest(proto.Message):
+    r"""Request for
+    [ResetQueuedResource][google.cloud.tpu.v2alpha1.Tpu.ResetQueuedResource].
+
+    Attributes:
+        name (str):
+            Required. The name of the queued resource.
+    """
+
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ServiceIdentity(proto.Message):
@@ -1841,4 +1974,66 @@ class ShieldedInstanceConfig(proto.Message):
     )
 
 
+class BootDiskConfig(proto.Message):
+    r"""Boot disk configurations.
+
+    Attributes:
+        customer_encryption_key (google.cloud.tpu_v2alpha1.types.CustomerEncryptionKey):
+            Optional. Customer encryption key for boot
+            disk.
+        enable_confidential_compute (bool):
+            Optional. Whether the boot disk will be
+            created with confidential compute mode.
+    """
+
+    customer_encryption_key: "CustomerEncryptionKey" = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="CustomerEncryptionKey",
+    )
+    enable_confidential_compute: bool = proto.Field(
+        proto.BOOL,
+        number=2,
+    )
+
+
+class CustomerEncryptionKey(proto.Message):
+    r"""Customer's encryption key.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
+    Attributes:
+        kms_key_name (str):
+            The name of the encryption key that is stored in Google
+            Cloud KMS. For example:
+
+            .. raw:: html
+
+                <pre class="lang-html">"kmsKeyName": "projects/
+                <var class="apiparam">kms_project_id</var>/locations/
+                <var class="apiparam">region</var>/keyRings/<var class="apiparam">
+                key_region</var>/cryptoKeys/<var class="apiparam">key</var>
+                </pre>
+
+            The fully-qualifed key name may be returned for resource GET
+            requests. For example:
+
+            .. raw:: html
+
+                <pre class="lang-html">"kmsKeyName": "projects/
+                <var class="apiparam">kms_project_id</var>/locations/
+                <var class="apiparam">region</var>/keyRings/<var class="apiparam">
+                key_region</var>/cryptoKeys/<var class="apiparam">key</var>
+                /cryptoKeyVersions/1</pre>
+
+            This field is a member of `oneof`_ ``key``.
+    """
+
+    kms_key_name: str = proto.Field(
+        proto.STRING,
+        number=7,
+        oneof="key",
+    )
+
+
 __all__ = tuple(sorted(__protobuf__.manifest))
